==> hu35ksubb.db_2.2.11.tar.gz: hu35ksubb.db/man/hu35ksubb_dbconn.Rd <==
\name{hu35ksubb_dbconn}

\alias{hu35ksubb_dbconn}
\alias{hu35ksubb_dbfile}
\alias{hu35ksubb_dbschema}
\alias{hu35ksubb_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  hu35ksubb_dbconn()
  hu35ksubb_dbfile()
  hu35ksubb_dbschema(file="", show.indices=FALSE)
  hu35ksubb_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{hu35ksubb_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{hu35ksubb_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{hu35ksubb_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{hu35ksubb_dbschema} prints the schema definition of the
  package annotation DB.

  \code{hu35ksubb_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{hu35ksubb_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{hu35ksubb_dbfile}: a character string with the path to the
  package annotation DB.

  \code{hu35ksubb_dbschema}: none (invisible \code{NULL}).

  \code{hu35ksubb_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(hu35ksubb_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by hu35ksubb_dbconn() was created with:
  dbConnect(SQLite(), dbname=hu35ksubb_dbfile(), cache_size=64000, synchronous=0)

  hu35ksubb_dbschema()

  hu35ksubb_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> hu35ksubb.db_2.14.0.tar.gz: hu35ksubb.db/man/hu35ksubb_dbconn.Rd <==

\name{hu35ksubb_dbconn}

\alias{hu35ksubb_dbconn}
\alias{hu35ksubb_dbfile}
\alias{hu35ksubb_dbschema}
\alias{hu35ksubb_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  hu35ksubb_dbconn()
  hu35ksubb_dbfile()
  hu35ksubb_dbschema(file="", show.indices=FALSE)
  hu35ksubb_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{hu35ksubb_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{hu35ksubb_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{hu35ksubb_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{hu35ksubb_dbschema} prints the schema definition of the
  package annotation DB.

  \code{hu35ksubb_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{hu35ksubb_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{hu35ksubb_dbfile}: a character string with the path to the
  package annotation DB.

  \code{hu35ksubb_dbschema}: none (invisible \code{NULL}).

  \code{hu35ksubb_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(hu35ksubb_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by hu35ksubb_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=hu35ksubb_dbfile(), cache_size=64000,
  synchronous=0)

  hu35ksubb_dbschema()

  hu35ksubb_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
